;; base16-silk-light-theme.el -- A base16 colorscheme

;;; Commentary:
;; Base16: (https://github.com/tinted-theming/home)

;;; Authors:
;; Scheme: Gabriel Fontes (https://github.com/Misterio77)
;; Template: Kaleb Elwert <belak@coded.io>

;;; Code:

(require 'base16-theme)

(defvar base16-silk-light-theme-colors
  '(:base00 "#e9f1ef"
    :base01 "#ccd4d3"
    :base02 "#90b7b6"
    :base03 "#5c787b"
    :base04 "#4b5b5f"
    :base05 "#385156"
    :base06 "#0e3c46"
    :base07 "#d2faff"
    :base08 "#cf432e"
    :base09 "#d27f46"
    :base0A "#cfad25"
    :base0B "#6ca38c"
    :base0C "#329ca2"
    :base0D "#39aac9"
    :base0E "#6e6582"
    :base0F "#865369")
  "All colors for Base16 Silk Light are defined here.")

;; Define the theme
(deftheme base16-silk-light)

;; Add all the faces to the theme
(base16-theme-define 'base16-silk-light base16-silk-light-theme-colors)

;; Mark the theme as provided
(provide-theme 'base16-silk-light)

(provide 'base16-silk-light-theme)

;;; base16-silk-light-theme.el ends here
