;; base16-measured-dark-theme.el -- A base16 colorscheme

;;; Commentary:
;; Base16: (https://github.com/tinted-theming/home)

;;; Authors:
;; Scheme: Measured (https://measured.co)
;; Template: Kaleb Elwert <belak@coded.io>

;;; Code:

(require 'base16-theme)

(defvar base16-measured-dark-theme-colors
  '(:base00 "#00211f"
    :base01 "#003a38"
    :base02 "#005453"
    :base03 "#ababab"
    :base04 "#c3c3c3"
    :base05 "#dcdcdc"
    :base06 "#efefef"
    :base07 "#f5f5f5"
    :base08 "#ce7e8e"
    :base09 "#dca37c"
    :base0A "#bfac4e"
    :base0B "#56c16f"
    :base0C "#62c0be"
    :base0D "#88b0da"
    :base0E "#b39be0"
    :base0F "#d89aba")
  "All colors for Base16 Measured Dark are defined here.")

;; Define the theme
(deftheme base16-measured-dark)

;; Add all the faces to the theme
(base16-theme-define 'base16-measured-dark base16-measured-dark-theme-colors)

;; Mark the theme as provided
(provide-theme 'base16-measured-dark)

(provide 'base16-measured-dark-theme)

;;; base16-measured-dark-theme.el ends here
