;; base16-ia-dark-theme.el -- A base16 colorscheme

;;; Commentary:
;; Base16: (https://github.com/tinted-theming/home)

;;; Authors:
;; Scheme: iA Inc. (modified by aramisgithub)
;; Template: Kaleb Elwert <belak@coded.io>

;;; Code:

(require 'base16-theme)

(defvar base16-ia-dark-theme-colors
  '(:base00 "#1a1a1a"
    :base01 "#222222"
    :base02 "#1d414d"
    :base03 "#767676"
    :base04 "#b8b8b8"
    :base05 "#cccccc"
    :base06 "#e8e8e8"
    :base07 "#f8f8f8"
    :base08 "#d88568"
    :base09 "#d86868"
    :base0A "#b99353"
    :base0B "#83a471"
    :base0C "#7c9cae"
    :base0D "#8eccdd"
    :base0E "#b98eb2"
    :base0F "#8b6c37")
  "All colors for Base16 iA Dark are defined here.")

;; Define the theme
(deftheme base16-ia-dark)

;; Add all the faces to the theme
(base16-theme-define 'base16-ia-dark base16-ia-dark-theme-colors)

;; Mark the theme as provided
(provide-theme 'base16-ia-dark)

(provide 'base16-ia-dark-theme)

;;; base16-ia-dark-theme.el ends here
